==> spip_4.0.4.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Willkommen @nom@ !',
	'c_accueil_configurer_site' => 'Ihre Website konfigurieren',
	'c_accueil_configurer_site_texte' => 'Vor allem Anderen sollten Sie Ihrer Website einen Namen geben.
		Zur Zeit heißt sie « @nom@ ». Der Name der Site wird oben auf dieser Seite angezeigt.
		Wenn ihn anklicken, können Sie ihn ändern oder ihn mit einem Logo und einem Slogan ergänzen.',
	'c_accueil_publication' => 'Veröffentlichen!',
	'c_accueil_publication_texte' => 'Um eine neue Seite zu veröffentlichen, benötigen Sie einen Artikel.
		Dazu müssen Sie zuvor mindestens eine Rubrik anlegen. Sie können das im Menü  « Redaktion » machen, indem Sie auf « Rubriken » klicken.',
	'c_accueil_texte' => 'Sie befinden sich jetzt im Redaktionsbereich von SPIP.',
	'c_accueil_texte_revenir' => '		Diese Seite gibt Ihnen einen Überblick über die Veröffentlichungsaktivität auf Ihrer Website.
		Sie können sie jederzeit wieder öffnen, indem Sie auf das Haus-Symbol links oben direkt unter 
                Ihrem Namen klicken.',
	'c_article_redaction' => 'Der Artikel ist in Bearbeitung.',
	'c_article_redaction_redacteur' => 'Der Artikel befindet sich in Bearbeitung.',
	'c_article_redaction_redacteur_texte' => 'Um Ihren Artikel den Admins und Redakteuren vor der Veröffentlichung vorzulegen,
		ändern Sie im Kasten links auf der Seite « in Bearbeitung » nach « vorgeschlagen ».',
	'c_article_redaction_texte' => 'Um diesen Artikel zu veröffentlichen, müssen Sie seinen Status ändern. Ändern Sie dazu im Kasten links  «in Bearbeitung» zu «veröffentlicht».',
	'c_articles_creer' => 'Wie werden Artikel erstellt?',
	'c_articles_creer_texte' => 'Sie können auf dieser Seite nur Artikel erstellen, wenn Ihre Website mindestens eine Rubrik enthält. Sie können eine über den Menüpunkt  « Redaktion» im Unterbereich « Rubriken» anlegen.',
	'c_job' => 'Anstehende Aufgaben',
	'c_job_texte' => 'Diese Seite zeigt Wartungsaufgaben, die SPIP regelmäßig erledigen muß. Diese Aufgaben erledigt SPIP entweder automatisch in bestimmten Abständen oder auf besondere Anforderung durch Plugins, etwa um einen Massenversand von Mails zu erledigen.',
	'c_rubrique_publier' => 'Legen Sie einen Artikel an.',
	'c_rubrique_publier_texte' => 'Rubriken werden auf den öffentlichen Seiten nur angezeigt, wenn sie Inhalte enthalten, etwa einen veröffentlichten Artikel.#
Legen Sie einen Artikel an. Sie können das auf dieser Seite unterhalb der Beschreibung der Rubrik machen.',
	'c_rubriques_creer' => 'Legen Sie eine erste Rubrik an!',
	'c_rubriques_creer_texte' => 'Die Website setzt sich aus Rubriken zusammen. Artikel legen sie innerhalb der Rubriken an.
Beginnen Sie, indem Sie eine erste Rubrik anlegen.',
	'c_sites_creer' => 'So erstellen oder importieren Sie eine Website?',
	'c_sites_creer_texte' => 'Sie können eine Website nicht erstellen oder importieren auf dieser Seite bis zu dem Moment, wo es einen Theme in Ihrer Website existiert. Sie können es aus dem Menü ’Bearbeiten’, dann ’Themen’ erstellen.',

	// E
	'explication_activer_compagnon' => 'Der Begleiter fügt manchen internen Seiten von SPIP Erläuterungen
hinzu, um Sie bei der Nutzung von SPIP zu unterstützen.
			Möchten sie ihn aktivieren ?',
	'explication_reinitialiser_compagnon' => 'Bereits gelesene Meldungen werden nicht erneut angezeigt.
			Möchten Sie diese Meldungen zurücksetzen?',

	// L
	'label_activer_compagnon' => 'Begleiter aktivieren?',
	'label_reinitialiser_compagnon' => 'Meldungen des Begleiters zurücksetzen?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Gut!',
	'ok_jai_compris' => 'Verstanden!',
	'ok_merci' => 'Danke',
	'ok_parfait' => 'Toll!',

	// R
	'reinitialisation' => 'Zurücksetzen',
	'reinitialisation_ok' => 'Das Zurücksetzen wurde ausgeführt.',
	'reinitialiser' => 'Zurücksetzen',
	'reinitialiser_moi' => 'Ja, für bereits gelesene.',
	'reinitialiser_tous' => 'Ja, für alle Autoren',

	// T
	'titre_compagnon' => 'Begleiter',
	'titre_page_configurer_compagnon' => 'Einstellungen des Begleiters'
);

==> spip_4.1.11+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'Alle Nachrichten des Begleiters ausblenden',
	'bouton_tout_compris_explication' => 'Wenn Sie SPIP bereits kennen, können Sie sich dafür entscheiden, alle Nachrichten des Begleiters zu ignorieren; andernfalls kann jede Nachricht einzeln geschlossen werden.',

	// C
	'c_accueil_bienvenue' => 'Willkommen @nom@ !',
	'c_accueil_configurer_site' => 'Ihre Website konfigurieren',
	'c_accueil_configurer_site_texte' => 'Vor allem Anderen sollten Sie Ihrer Website einen Namen geben.
		Zur Zeit heißt sie « @nom@ ». Der Name der Site wird oben auf dieser Seite angezeigt.
		Wenn ihn anklicken, können Sie ihn ändern oder ihn mit einem Logo und einem Slogan ergänzen.',
	'c_accueil_publication' => 'Veröffentlichen!',
	'c_accueil_publication_texte' => 'Um eine neue Seite zu veröffentlichen, benötigen Sie einen Artikel.
		Dazu müssen Sie zuvor mindestens eine Rubrik anlegen. Sie können das im Menü  « Redaktion » machen, indem Sie auf « Rubriken » klicken.',
	'c_accueil_texte' => 'Sie befinden sich jetzt im Redaktionsbereich von SPIP.',
	'c_accueil_texte_revenir' => '		Diese Seite gibt Ihnen einen Überblick über die Veröffentlichungsaktivität auf Ihrer Website.
		Sie können sie jederzeit wieder öffnen, indem Sie auf das Haus-Symbol links oben direkt unter 
                Ihrem Namen klicken.',
	'c_article_redaction' => 'Der Artikel ist in Bearbeitung.',
	'c_article_redaction_redacteur' => 'Der Artikel befindet sich in Bearbeitung.',
	'c_article_redaction_redacteur_texte' => 'Um Ihren Artikel den Admins und Redakteuren vor der Veröffentlichung vorzulegen,
		ändern Sie im Kasten links auf der Seite « in Bearbeitung » nach « vorgeschlagen ».',
	'c_article_redaction_texte' => 'Um diesen Artikel zu veröffentlichen, müssen Sie seinen Status ändern. Ändern Sie dazu im Kasten links  «in Bearbeitung» zu «veröffentlicht».',
	'c_articles_creer' => 'Wie werden Artikel erstellt?',
	'c_articles_creer_texte' => 'Sie können auf dieser Seite nur Artikel erstellen, wenn Ihre Website mindestens eine Rubrik enthält. Sie können eine über den Menüpunkt  « Redaktion» im Unterbereich « Rubriken» anlegen.',
	'c_job' => 'Anstehende Aufgaben',
	'c_job_texte' => 'Diese Seite zeigt Wartungsaufgaben, die SPIP regelmäßig erledigen muß. Diese Aufgaben erledigt SPIP entweder automatisch in bestimmten Abständen oder auf besondere Anforderung durch Plugins, etwa um einen Massenversand von Mails zu erledigen.',
	'c_rubrique_publier' => 'Legen Sie einen Artikel an.',
	'c_rubrique_publier_texte' => 'Rubriken werden auf den öffentlichen Seiten nur angezeigt, wenn sie Inhalte enthalten, etwa einen veröffentlichten Artikel.#
Legen Sie einen Artikel an. Sie können das auf dieser Seite unterhalb der Beschreibung der Rubrik machen.',
	'c_rubriques_creer' => 'Legen Sie eine erste Rubrik an!',
	'c_rubriques_creer_texte' => 'Die Website setzt sich aus Rubriken zusammen. Artikel legen sie innerhalb der Rubriken an.
Beginnen Sie, indem Sie eine erste Rubrik anlegen.',
	'c_sites_creer' => 'So erstellen oder importieren Sie eine Website?',
	'c_sites_creer_texte' => 'Sie können eine Website nicht erstellen oder importieren auf dieser Seite bis zu dem Moment, wo es einen Theme in Ihrer Website existiert. Sie können es aus dem Menü ’Bearbeiten’, dann ’Themen’ erstellen.',

	// E
	'explication_activer_compagnon' => 'Der Begleiter fügt manchen internen Seiten von SPIP Erläuterungen
hinzu, um Sie bei der Nutzung von SPIP zu unterstützen.
			Möchten sie ihn aktivieren ?',
	'explication_reinitialiser_compagnon' => 'Bereits gelesene Meldungen werden nicht erneut angezeigt.
			Möchten Sie diese Meldungen zurücksetzen?',

	// L
	'label_activer_compagnon' => 'Begleiter aktivieren?',
	'label_reinitialiser_compagnon' => 'Meldungen des Begleiters zurücksetzen?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Gut!',
	'ok_jai_compris' => 'Verstanden!',
	'ok_merci' => 'Danke',
	'ok_parfait' => 'Toll!',

	// R
	'reinitialisation' => 'Zurücksetzen',
	'reinitialisation_ok' => 'Das Zurücksetzen wurde ausgeführt.',
	'reinitialiser' => 'Zurücksetzen',
	'reinitialiser_moi' => 'Ja, für bereits gelesene.',
	'reinitialiser_tous' => 'Ja, für alle Autoren',

	// T
	'titre_compagnon' => 'Begleiter',
	'titre_page_configurer_compagnon' => 'Einstellungen des Begleiters'
);
